<div id="booking-errors">
{% if form.errors %}
    {% for field in form %}
        {% for error in field.errors %} 
            <div class="alert alert-danger">
                <strong>({{field.label}})</strong>, {{ error|escape }}
            </div>
        {% endfor %}
    {% endfor %}
    <hr>
{% endif %}
</div>