#notifications {
  right: 0;
  position: fixed;
  top: 0;

  z-index: 1;
}

.ml-auto {
  margin-left: auto !important;
}

a {
  color: #ffffff80;
}

a:hover {
  color: #fff;
}

.active a {
  color: #fff;
}

.section {
  position: relative;
  height: 100vh;
}

.section .section-center {
  position: absolute;
  top: 50%;
  left: 0;
  right: 0;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%);
}

#booking {
  font-family: 'Lato', sans-serif;
  background-size: cover;
  background-position: center;
  color: #191a1e;
}

.booking-form {
  position: relative;
  background: #fff;
  max-width: 642px;
  width: 100%;
  margin: auto;
  padding: 45px 25px 25px;
  border-radius: 4px;
  -webkit-box-shadow: 0px 0px 10px -5px rgba(0, 0, 0, 0.4);
  box-shadow: 0px 0px 10px -5px rgba(0, 0, 0, 0.4);
}

.booking-form select.form-control + .select-arrow {
  position: absolute;
  right: 6px;
  bottom: 6px;
  width: 32px;
  line-height: 32px;
  height: 32px;
  text-align: center;
  pointer-events: none;
  color: #dfe5e9;
  font-size: 14px;
}

.booking-form select.form-control + .select-arrow:after {
  content: '\279C';
  display: block;
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
}

.booking-cta {
  margin-top: 45px;
}

.booking-cta h1 {
  font-size: 52px;
  text-transform: uppercase;
  color: #4fa3e3;
  font-weight: 400;
}

.booking-cta p {
  font-size: 22px;
  color: #dfe5e9;
}

.primary-card {
  border-left: 4px solid #0d6efd;
}

.success-card {
  border-left: 4px solid #198754;
}

.info-card {
  border-left: 4px solid #0dcaf0;
}

.warning-card {
  border-left: 4px solid #ffc107;
}

#pills-time .bg-secondary{
  cursor:no-drop;
}

#pills-time .bg-light{
  cursor: pointer;
}

/*# sourceMappingURL=style.css.map */